==> 0.5.0.tar.gz: test/services/configuration_test.dart <==
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';

/// Tests the features of the [Configuration] class.
void main() => group('Configuration', () {
  group('.keys', () {
    test('should return an empty array for an empty configuration', () {
      expect(new Configuration(const <String, dynamic>{}).keys, isEmpty);
    });

    test('should return the list of keys for a non-empty configuration', () {
      expect(new Configuration(const <String, dynamic>{'foo': 'bar', 'baz': 'qux'}).keys, orderedEquals(const <String>['foo', 'baz']));
    });
  });

  group('.onChanges', () {
    var config = new Configuration(const <String, dynamic>{});

    test('should trigger an event when a value is added', () {
      var subscription = config.onChanges.listen((changes) {
        expect(changes.keys, orderedEquals(const <String>['foo']));
        expect(changes['foo'].previousValue, isNull);
        expect(changes['foo'].currentValue, equals('bar'));
      });

      config['foo'] = 'bar';
      subscription.cancel();
    });

    test('should trigger an event when a value is updated', () {
      var subscription = config.onChanges.listen((changes) {
        expect(changes.keys, orderedEquals(const <String>['foo']));
        expect(changes['foo'].previousValue, equals('bar'));
        expect(changes['foo'].currentValue, equals('baz'));
      });

      config['foo'] = 'baz';
      subscription.cancel();
    });

    test('should trigger an event when a value is removed', () {
      var subscription = config.onChanges.listen((changes) {
        expect(changes.keys, orderedEquals(const <String>['foo']));
        expect(changes['foo'].previousValue, equals('bar'));
        expect(changes['foo'].currentValue, isNull);
      });

      config.remove('foo');
      subscription.cancel();
    });
  });

  group('operator [] / operator []=', () {
    var config = new Configuration(const <String, dynamic>{'foo': 'bar'});

    test('should properly get the configuration entries', () {
      expect(config['foo'], equals('bar'));
      expect(config['baz'], isNull);
    });

    test('should properly set the configuration entries', () {
      config['foo'] = 666;
      expect(config['foo'], equals(666));

      config['baz'] = 'qux';
      expect(config['baz'], equals('qux'));
    });
  });

  group('.clear()', () {
    test('should properly remove all the configuration entries', () {
      var config = new Configuration(const <String, dynamic>{'foo': 'bar', 'baz': 'qux'});
      expect(config, hasLength(2));
      config.clear();
      expect(config, isEmpty);
    });
  });

  group('.remove()', () {
    test('should properly remove the configuration entries', () {
      var config = new Configuration(const <String, dynamic>{'foo': 'bar', 'baz': 'qux'});
      expect(config, hasLength(2));

      config.remove('foo');
      expect(config['foo'], isNull);
      expect(config, hasLength(1));

      config.remove('baz');
      expect(config, isEmpty);
    });
  });
});

==> 0.7.0.tar.gz: test/services/configuration_test.dart <==
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';

/// Tests the features of the [Configuration] class.
void main() => group('Configuration', () {
  group('.keys', () {
    test('should return an empty array for an empty configuration', () {
      expect(new Configuration(const <String, Object>{}).keys, isEmpty);
    });

    test('should return the list of keys for a non-empty configuration', () {
      expect(new Configuration(const <String, Object>{'foo': 'bar', 'baz': 'qux'}).keys, orderedEquals(const <String>['foo', 'baz']));
    });
  });

  group('.onChanges', () {
    var config = new Configuration(const <String, Object>{});

    test('should trigger an event when a value is added', () {
      var subscription = config.onChanges.listen((changes) {
        expect(changes.keys, orderedEquals(const <String>['foo']));
        expect(changes['foo'].previousValue, isNull);
        expect(changes['foo'].currentValue, equals('bar'));
      });

      config['foo'] = 'bar';
      subscription.cancel();
    });

    test('should trigger an event when a value is updated', () {
      var subscription = config.onChanges.listen((changes) {
        expect(changes.keys, orderedEquals(const <String>['foo']));
        expect(changes['foo'].previousValue, equals('bar'));
        expect(changes['foo'].currentValue, equals('baz'));
      });

      config['foo'] = 'baz';
      subscription.cancel();
    });

    test('should trigger an event when a value is removed', () {
      var subscription = config.onChanges.listen((changes) {
        expect(changes.keys, orderedEquals(const <String>['foo']));
        expect(changes['foo'].previousValue, equals('bar'));
        expect(changes['foo'].currentValue, isNull);
      });

      config.remove('foo');
      subscription.cancel();
    });
  });

  group('operator [] / operator []=', () {
    var config = new Configuration(const <String, Object>{'foo': 'bar'});

    test('should properly get the configuration entries', () {
      expect(config['foo'], equals('bar'));
      expect(config['baz'], isNull);
    });

    test('should properly set the configuration entries', () {
      config['foo'] = 666;
      expect(config['foo'], equals(666));

      config['baz'] = 'qux';
      expect(config['baz'], equals('qux'));
    });
  });

  group('.clear()', () {
    test('should properly remove all the configuration entries', () {
      var config = new Configuration(const <String, Object>{'foo': 'bar', 'baz': 'qux'});
      expect(config, hasLength(2));
      config.clear();
      expect(config, isEmpty);
    });
  });

  group('.remove()', () {
    test('should properly remove the configuration entries', () {
      var config = new Configuration(const <String, Object>{'foo': 'bar', 'baz': 'qux'});
      expect(config, hasLength(2));

      config.remove('foo');
      expect(config['foo'], isNull);
      expect(config, hasLength(1));

      config.remove('baz');
      expect(config, isEmpty);
    });
  });
});
